summaryrefslogtreecommitdiffstats
path: root/superkaramba/examples/unicode/unicode.py
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:17 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:17 -0600
commit955e20356d63ed405198c8143617a8a0ca8bfc02 (patch)
tree9a9ab22c86d212a5655014ad752e96b04c0c86a9 /superkaramba/examples/unicode/unicode.py
parentbf280726d5d22f33d33e4f9e771220c725249407 (diff)
downloadtdeutils-955e20356d63ed405198c8143617a8a0ca8bfc02.tar.gz
tdeutils-955e20356d63ed405198c8143617a8a0ca8bfc02.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit bf280726d5d22f33d33e4f9e771220c725249407.
Diffstat (limited to 'superkaramba/examples/unicode/unicode.py')
-rw-r--r--superkaramba/examples/unicode/unicode.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/superkaramba/examples/unicode/unicode.py b/superkaramba/examples/unicode/unicode.py
index 13d1136..1a15f83 100644
--- a/superkaramba/examples/unicode/unicode.py
+++ b/superkaramba/examples/unicode/unicode.py
@@ -1,6 +1,6 @@
#Unicode Example
#For Symbol Tables look at www.unicode.org/charts/
#this import statement allows access to the karamba functions
@@ -31,8 +31,8 @@ def initWidget(widget):
\u0631\u0632\u0633\u0634\u0635\u0636\u0637\u0638\u0639\u063A\u0641\u0642\u0643\u0644\u0645\u0646
\u0647\u0648\u064A
<p>
-For a complete reference on unicode caracter codes look at:
-<center><a href="kfmclient openURL http://www.unicode.org/charts/">www.unicode.org/charts/</a></center>
+For a complete reference on tqunicode caracter codes look at:
+<center><a href="kfmclient openURL http://www.tqunicode.org/charts/">www.tqunicode.org/charts/</a></center>
</p>
"""
karamba.resizeWidget(widget, 400, 400)
@@ -1,6 +1,6 @@
#Unicode Example
-#For Symbol Tables look at www.unicode.org/charts/
+#For Symbol Tables look at www.tqunicode.org/charts/
#this import statement allows access to the karamba functions